<?php
define('nl', chr(10));

function isPath($file)
{
    if (strlen($file) < 256 && (strpos($file, "/") || strpos($file, "\\")))
    {
        if (file_exists($file))
        {
            return true;
        }
        throw new BarcodeException("Path does not exist", __FILE__, __LINE__);
    }
    return false;
}

function convertResourceToBase64String($resource)
{
    try
    {
        if (isPath($resource))
        {
            $resourceData = file_get_contents($resource);
            return base64_encode($resourceData);
        }
        else
        {
            return $resource;
        }
    }
    catch (Exception $ex)
    {
        throw new BarcodeException($ex->getMessage(), __FILE__, __LINE__);
    }
}

class License extends BaseJavaClass
{
    protected $javaClassName = "com.aspose.php.barcode.license.PhpLicense";

    public function __construct()
    {
        parent::__construct(new java($this->javaClassName));
    }

    public function setLicense($filePath)
    {
        try
        {
            $file_data = self::openFile($filePath);
            $this->getJavaClass()->setLicense($file_data);
        }
        catch (Exception $ex)
        {
            throw new BarcodeException($ex->getMessage(), __FILE__, __LINE__);
        }
    }

    public function resetLicense()
    {
        try
        {
            $this->getJavaClass()->resetLicense();
        }
        catch (Exception $ex)
        {
            throw new BarcodeException($ex->getMessage(), __FILE__, __LINE__);
        }
    }

    public function isLicensed()
    {
        try
        {
            $is_licensed = $this->getJavaClass()->isLicensed();
            return strval($is_licensed);
        }
        catch (Exception $ex)
        {
            throw new BarcodeException($ex->getMessage(), __FILE__, __LINE__);
        }


    }

    private static function openFile($filename)
    {
        try
        {
            return unpack("C*", file_get_contents($filename));
        }
        catch (Exception $ex)
        {
            throw new BarcodeException($ex->getMessage(), __FILE__, __LINE__);
        }


    }

    protected function init()
    {
//      do nothing
    }
}

class Point extends BaseJavaClass
{
    private const javaClassName = "java.awt.Point";

    /**
     * Represents a Quadrangle structure with its properties left uninitialized.Value: Quadrangle
     */
    public static function EMPTY()
    {
        return new Point(0, 0);
    }

    /**
     * Rectangle constructor.
     * @param $x
     * @param $y
     */
    public function __construct($x, $y)
    {
        try
        {
            parent::__construct(new java(self::javaClassName, $x, $y));
        }
        catch (Exception $ex)
        {
            throw new BarcodeException($ex->getMessage(), __FILE__, __LINE__);
        }


    }

    static function construct(...$args) 
    {
        try
        {
            $point = self::EMPTY();
            $point->setJavaClass($args[0]);
            return $point;
        }
        catch (Exception $ex)
        {
            throw new BarcodeException($ex->getMessage(), __FILE__, __LINE__);
        }


    }

    protected function init()
    {
        // TODO: Implement init() method.
    }

    public function getX()
    {
        try
        {
            return java_cast($this->getJavaClass()->getX(), "integer");
        }
        catch (Exception $ex)
        {
            throw new BarcodeException($ex->getMessage(), __FILE__, __LINE__);
        }


    }

    public function getY()
    {
        try
        {
            return java_cast($this->getJavaClass()->getY(), "integer");
        }
        catch (Exception $ex)
        {
            throw new BarcodeException($ex->getMessage(), __FILE__, __LINE__);
        }


    }

    public function setX($x)
    {
        try
        {
            $this->getJavaClass()->x = $x;
        }
        catch (Exception $ex)
        {
            throw new BarcodeException($ex->getMessage(), __FILE__, __LINE__);
        }


    }

    public function setY($y)
    {
        try
        {
            $this->getJavaClass()->y = $y;
        }
        catch (Exception $ex)
        {
            throw new BarcodeException($ex->getMessage(), __FILE__, __LINE__);
        }


    }

    public function toString() 
    {
        try
        {
            return $this->getJavaClass()->getX() . ',' . $this->getJavaClass()->getY();
        }
        catch (Exception $ex)
        {
            throw new BarcodeException($ex->getMessage(), __FILE__, __LINE__);
        }


    }

    public function equals($obj)
    {
        try
        {
            return java_cast($this->getJavaClass()->equals($obj->getJavaClass()), "boolean");
        }
        catch (Exception $ex)
        {
            throw new BarcodeException($ex->getMessage(), __FILE__, __LINE__);
        }


    }
}

class Rectangle extends BaseJavaClass
{
    private const javaClassName = "java.awt.Rectangle";

    /**
     * Represents a Quadrangle structure with its properties left uninitialized.Value: Quadrangle
     */
    public static function EMPTY()
    {
        try
        {
            return new Rectangle(0, 0,0,0);
        }
        catch (Exception $ex)
        {
            throw new BarcodeException($ex->getMessage(), __FILE__, __LINE__);
        }


    }

    /**
     * Rectangle constructor.
     * @param $x
     * @param $y
     */
    public function __construct($x, $y, $width, $height)
    {
        try
        {
            parent::__construct(new java(self::javaClassName, $x, $y, $width, $height));
        }
        catch (Exception $ex)
        {
            throw new BarcodeException($ex->getMessage(), __FILE__, __LINE__);
        }


    }

    static function construct(...$args) 
    {
        try
        {
            $rectangle = self::EMPTY();
            $rectangle->setJavaClass($args[0]);
            return $rectangle;

        }
        catch (Exception $ex)
        {
            throw new BarcodeException($ex->getMessage(), __FILE__, __LINE__);
        }


    }

    public function getX()
    {
        try
        {
            return java_cast($this->getJavaClass()->getX(), "integer");
        }
        catch (Exception $ex)
        {
            throw new BarcodeException($ex->getMessage(), __FILE__, __LINE__);
        }


    }

    public function getY()
    {
        try
        {
            return java_cast($this->getJavaClass()->getY(), "integer");
        }
        catch (Exception $ex)
        {
            throw new BarcodeException($ex->getMessage(), __FILE__, __LINE__);
        }


    }

    public function getLeft()
    {
        return $this->getX();
    }

    public function getTop()
    {
        return $this->getY();
    }

    public function getRight()
    {
        return $this->getX() + $this->getWidth();
    }

    public function getBottom()
    {
        return $this->getY() + $this->getHeight();
    }

    public function getWidth()
    {
        try
        {
            return java_cast($this->getJavaClass()->getWidth(), "integer");
        }
        catch (Exception $ex)
        {
            throw new BarcodeException($ex->getMessage(), __FILE__, __LINE__);
        }


    }

    public function getHeight()
    {
        try
        {
            return java_cast($this->getJavaClass()->getHeight(), "integer");
        }
        catch (Exception $ex)
        {
            throw new BarcodeException($ex->getMessage(), __FILE__, __LINE__);
        }


    }

    public function toString() 
    {
        try
        {
            return $this->getX() . ',' . $this->getY() . ',' . $this->getWidth() . ',' . $this->getHeight();
        }
        catch (Exception $ex)
        {
            throw new BarcodeException($ex->getMessage(), __FILE__, __LINE__);
        }


    }

    public function equals($obj) 
    {
        try
        {
            return java_cast($this->getJavaClass()->equals($obj->getJavaClass()), "boolean");
        }
        catch (Exception $ex)
        {
            throw new BarcodeException($ex->getMessage(), __FILE__, __LINE__);
        }


    }

    private function intersectsWithInclusive($r) 
    {
        try
        {
            return !(($this->getLeft() > $r->getRight()) || ($this->getRight() < $r->getLeft()) ||
                ($this->getTop() > $r->getBottom()) || ($this->getBottom() < $r->getTop()));
        }
        catch (Exception $ex)
        {
            throw new BarcodeException($ex->getMessage(), __FILE__, __LINE__);
        }


    }

    /**
     * Intersect Shared Method
     * Produces a new Rectangle by intersecting 2 existing
     * Rectangles. Returns null if there is no    intersection.
     */

    public static function intersect($a, $b)
    {
        try
        {
            // MS.NET returns a non-empty rectangle if the two rectangles
            // touch each other
            if (!$a->intersectsWithInclusive($b))
            {
                return new Rectangle(0, 0, 0, 0);
            }

            return Rectangle::fromLTRB(
                max($a->getLeft(), $b->getLeft()),
                max($a->getTop(), $b->getTop()),
                min($a->getRight(), $b->getRight()),
                min($a->getBottom(), $b->getBottom()));
        }
        catch (Exception $ex)
        {
            throw new BarcodeException($ex->getMessage(), __FILE__, __LINE__);
        }


    }

    /**
     * FromLTRB Shared Method
     * Produces a Rectangle structure from left, top, right,
     * and bottom coordinates.
     */

    public static function fromLTRB($left, $top, $right, $bottom)
    {
        try
        {
            return new Rectangle($left, $top, $right - $left,$bottom - $top);
        }
        catch (Exception $ex)
        {
            throw new BarcodeException($ex->getMessage(), __FILE__, __LINE__);
        }


    }

    public function isEmpty() 
    {
        try
        {
            return ($this->getWidth() <= 0) || ($this->getWidth() <= 0);
        }
        catch (Exception $ex)
        {
            throw new BarcodeException($ex->getMessage(), __FILE__, __LINE__);
        }


    }

    protected function init()
    {
        // TODO: Implement init() method.
    }
}

abstract class BaseJavaClass
{
    private $javaClass;
    private $javaClassName;

    function __construct($javaClass)
    {
        try
        {
            $this->javaClass = $javaClass;
            $this->init();

            if (empty($this->javaClassName))
            {
                $this->javaClassName = $this->javaClass->__signature;
            }
        }
        catch (Exception $ex)
        {
            throw new BarcodeException($ex->getMessage(), __FILE__, __LINE__);
        }
    }

    protected abstract function init();


    public function getJavaClass()
    {
        return $this->javaClass;
    }

    protected function setJavaClass($javaClass)
    {
        try
        {
            $this->javaClass= $javaClass;
            $this->init();
        }
        catch (Exception $ex)
        {
            throw new BarcodeException($ex->getMessage(), __FILE__, __LINE__);
        }


    }

    public function getJavaClassName()
    {
        try
        {
            return $this->javaClassName;
        }
        catch (Exception $ex)
        {
            throw new BarcodeException($ex->getMessage(), __FILE__, __LINE__);
        }


    }

    public function isNull()
    {
        try
        {
            return java_cast($this->javaClass->isNull(), "boolean");
        }
        catch (Exception $ex)
        {
            throw new BarcodeException($ex->getMessage(), __FILE__, __LINE__);
        }


    }

    public function printJavaClassName()
    {
        try
        {
            print("Java class name => '" . $this->javaClassName . "'");
        }
        catch (Exception $ex)
        {
            throw new BarcodeException($ex->getMessage(), __FILE__, __LINE__);
        }


    }
}

/**
 * Class BarcodeException
 */
class BarcodeException extends Exception
{
    const MAX_LINES = 34;

    /**
     * BarcodeException constructor.
     * @param  $exc exception's instance
     */
    public function __construct($message = "", $file="",$line="",$code = 0, $previous = null)
    {
        print "Exception occurred:".$message." at ".$file.":".$line."\n";
        parent::__construct($code, $code, $previous);
        if (is_string($message))
        {
            $this->setMessage($message);
            return;
        }
        $line = $this->getLine();
        $file = $this->getFile();
        $exc_message = "Exception occured in $file:$line" . nl;
        $details = $this->getDetails($message);

        if (empty($details))
        {
            $this->setMessage($exc_message);
            return;
        }
        $lines = explode("\n", $details);


        $counter = 0;
        foreach ($lines as $line)
        {
            if ($counter >= self::MAX_LINES)
            {
                break;
            }
            $counter++;
            $exc_message .= $line . nl;
        }
        $this->setMessage($exc_message);
    }

    private function getDetails($exc)
    {
        $details = "";
        if (is_string($exc))
        {
            return $exc;
        }
        if (get_class($exc) != null)
        {
            $details = "exception type : " . get_class($exc) . "\n";
        }
        if (method_exists($exc, "__toString"))
        {
            $details .= $exc->__toString();
        }
        if (method_exists($exc, "getMessage"))
        {
            $details .= $exc->getMessage();
        }
        if (method_exists($exc, "getCause"))
        {
            $details .= $exc->getCause();
        }
        return $details;
    }


    public function setMessage($message)
    {
        $this->message = $message;
    }

}

?>
